/*==========================================================
 * Program : gsmdev.h                      Project : smslink
 * Author  : Philippe Andersson.
 * Date    : 24/11/00
 * Version : 0.05b
 * Notice  : (c) Les Ateliers du Heron, 1998 for Scitex Europe, S.A.
 * Comment : GSM device "driver" include file for SMSLink server.
 *
 * Modification History :
 * - 0.01a (17/05/00) : Initial release.
 * ++++ Switched to Beta ++++
 * - 0.02b (08/06/00) : Added HAS_CS_AT_PARSER define for some
 *   Wavecom modules (the WM02 for sure).
 * - 0.03b (21/06/00) : Added define for Siemens M20 (sub-prompt
 *   when requesting to send).
 * - 0.04b (18/10/00) : Added alternate CNMI handling for Siemens
 *   S25 / S35 (thanks to Thomas Omerzu <thomas@omerzu.de> for
 *   the fix).
 * - 0.05 (24/11/00) : Added ALT_CNMI_2 and HAS_CSDH_1 to support
 *   the PCFF900 model. Kudos to Bernard Willemot 
 *   <bernard_willemot@cse.creoscitex.com> for lending me the
 *   hardware.
 *========================================================*/

#ifndef _GSMDEV_H
#define _GSMDEV_H

/* "Driver" file */
#define GSMCAPS_FILE		"/etc/gsmcaps"

#define MAXMODLEN		15      /* max length for model */

/* Capacity Flags */
#define HAS_TEXT_MODE		 1	/* Text mode supported */
#define HAS_PDU_MODE		 2	/* PDU mode supported */
#define STRICT_TEXT_PARAMS	 4	/* Params MUST be txt in txt mode */
#define HAS_SCA_IN_PDU	 	 8	/* SCA can be given in PDU */
                                        /* Note: NOT in GSM 03.40 (GENSM2) */
#define HAS_CS_AT_PARSER	16	/* Case-sensitive AT parser (WM02) */
#define SUBPROMPT_IN_CMGS       32      /* Wait for '>' after '\r' (SM20) */
#define ALT_CNMI        	64	/* Use CNMI=0,0,0,0,1 instead of  */
                                        /* 0,0,0,0,0 (SS25) */
#define ALT_CNMI_2             128	/* Use CNMI=1,0,0,0,0 (PCFF900) */
#define HAS_CSDH_1             256      /* Full header (not on PCFF900) */

/*==========================================================
 * Structure Declarations
 *========================================================*/

/*==========================================================
 * Function Declarations
 *========================================================*/
/* --- in ".c" --- */

#endif                               /* #ifndef _GSMDEV_H */

/*==========================================================
 * EOF : gsmdev.h
 *===================*/
